# Changelog

## [v0.1.0](https://github.com/py-img-gen/py-img-gen-lib/commits/v0.1.0) - 2025-02-21
- Initialize by @shunk031 in https://github.com/py-img-gen/py-img-gen-lib/pull/1
- add optional packages by @shunk031 in https://github.com/py-img-gen/py-img-gen-lib/pull/2
- update lib by @shunk031 in https://github.com/py-img-gen/py-img-gen-lib/pull/3
- Update for release by @shunk031 in https://github.com/py-img-gen/py-img-gen-lib/pull/4
